@@ -1,7 +1,11 @@
-#!/usr/bin/env python2
+#!/usr/bin/python2
+
+import gi
+gi.require_version("Gtk", "3.0")
+gi.require_version('CDesktopEnums', '3.0')
 
-from SettingsWidgets import *
 from gi.repository import Gtk, CDesktopEnums
+from GSettingsWidgets import *
 
 DPI_FACTOR_LARGE         = 1.25
 DPI_FACTOR_NORMAL        = 1.0
@@ -9,8 +13,12 @@ DPI_FACTOR_NORMAL        = 1.0
 HIGH_CONTRAST_THEME      = "HighContrast"
 KEY_TEXT_SCALING_FACTOR  = "text-scaling-factor"
 KEY_GTK_THEME            = "gtk-theme"
+KEY_GTK_THEME_BACKUP     = "gtk-theme-backup"
 KEY_ICON_THEME           = "icon-theme"
+KEY_ICON_THEME_BACKUP    = "icon-theme-backup"
 KEY_WM_THEME             = "theme"
+KEY_WM_THEME_BACKUP      = "theme-backup"
+
 
 class Module:
     name = "universal-access"
@@ -42,7 +50,7 @@ class Module:
 
             settings = page.add_section(_("Visual Aids"))
 
-            switch = GSettingsSwitch(_("High contrast"))
+            switch = Switch(_("High contrast"))
             self.iface_settings.bind_with_mapping(KEY_GTK_THEME,
                                                   switch.content_widget, "active",
                                                   Gio.SettingsBindFlags.DEFAULT,
@@ -50,7 +58,7 @@ class Module:
                                                   self.hi_con_set_mapping)
             settings.add_row(switch)
 
-            switch = GSettingsSwitch(_("Large text"))
+            switch = Switch(_("Large text"))
             self.iface_settings.bind_with_mapping(KEY_TEXT_SCALING_FACTOR,
                                                   switch.content_widget, "active",
                                                   Gio.SettingsBindFlags.DEFAULT,
@@ -59,11 +67,11 @@ class Module:
             settings.add_row(switch)
 
             switch = GSettingsDependencySwitch(_("Screen reader"),
-                                     "org.cinnamon.desktop.a11y.applications",
-                                     "screen-reader-enabled",
-                                     None,
-                                     ["orca"],
-                                     ["gnome-orca"])
+                                               "org.cinnamon.desktop.a11y.applications",
+                                               "screen-reader-enabled",
+                                               None,
+                                               ["orca"],
+                                               ["gnome-orca"])
             settings.add_row(switch)
 
 # Desktop Zoom
@@ -142,13 +150,26 @@ class Module:
 
             settings.add_row(switch)
 
-            keyboard_type_options = [["touch",     _("Touch")],
+            keyboard_type_options = [["tablet",     _("Tablet")],
+                                     ["touch",     _("Touch")],
                                      ["fullscale", _("Full scale")],
                                      ["scan",      _("Scanning")]]
 
             widget = GSettingsComboBox(_("Keyboard layout"), "org.cinnamon.keyboard", "keyboard-type", keyboard_type_options)
             settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
 
+            keyboard_position_options = [["bottom",     _("At the bottom of the screen")],
+                                         ["top",     _("At the top of the screen")]]
+            widget = GSettingsComboBox(_("Keyboard position"), "org.cinnamon.keyboard", "keyboard-position", keyboard_position_options)
+            settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
+
+            keyboard_size_options = [[4,     _("A quarter of the screen")],
+                                     [3,     _("A third of the screen")],
+                                     [2, _("Half of the screen")]]
+
+            widget = GSettingsComboBox(_("Keyboard size"), "org.cinnamon.keyboard", "keyboard-size", keyboard_size_options)
+            settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
+
             activation_mode_options = [["accessible", _("Show the keyboard any time something expects input")],
                                        ["on-demand",  _("Show keyboard only when the user activates it")]];
 
@@ -270,7 +291,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.keyboard",
                                     "slowkeys-delay",
                                     _("Short"), _("Long"),
-                                    0, 500, 10)
+                                    0, 500, 10, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.keyboard", "slowkeys-enable")
 
@@ -296,7 +317,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.keyboard",
                                     "bouncekeys-delay",
                                     _("Short"), _("Long"),
-                                    0, 900, 10)
+                                    0, 900, 10, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.keyboard", "bouncekeys-enable")
 
@@ -320,7 +341,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.keyboard",
                                     "mousekeys-init-delay",
                                     _("Shorter"), _("Longer"),
-                                    10, 2000, 10)
+                                    10, 2000, 10, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.keyboard", "mousekeys-enable")
 
@@ -328,7 +349,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.keyboard",
                                     "mousekeys-accel-time",
                                     _("Shorter"), _("Longer"),
-                                    10, 2000, 10)
+                                    10, 2000, 10, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.keyboard", "mousekeys-enable")
 
@@ -336,7 +357,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.keyboard",
                                     "mousekeys-max-speed",
                                     _("Slower"), _("Faster"),
-                                    1, 500, 1)
+                                    1, 500, 1, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.keyboard", "mousekeys-enable")
 
@@ -375,7 +396,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.mouse",
                                     "secondary-click-time",
                                     _("Shorter"), _("Longer"),
-                                    0.5, 3.0, 0.1)
+                                    0.5, 3.0, 0.1, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.mouse", "secondary-click-enabled")
 
@@ -395,7 +416,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.mouse",
                                     "dwell-time",
                                     _("Short"), _("Long"),
-                                    0.2, 3.0, 0.1)
+                                    0.2, 3.0, 0.1, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.mouse", "dwell-click-enabled")
 
@@ -403,7 +424,7 @@ class Module:
                                     "org.cinnamon.desktop.a11y.mouse",
                                     "dwell-threshold",
                                     _("Small"), _("Large"),
-                                    1, 30, 1)
+                                    1, 30, 1, show_value=False)
 
             settings.add_reveal_row(slider, "org.cinnamon.desktop.a11y.mouse", "dwell-click-enabled")
 
@@ -431,12 +452,24 @@ class Module:
         if active:
             ret = HIGH_CONTRAST_THEME
 
+            theme = self.iface_settings.get_string(KEY_GTK_THEME)
+            self.iface_settings.set_string(KEY_GTK_THEME_BACKUP, theme)
+
+            theme = self.iface_settings.get_string(KEY_ICON_THEME)
+            self.iface_settings.set_string(KEY_ICON_THEME_BACKUP, theme)
             self.iface_settings.set_string(KEY_ICON_THEME, HIGH_CONTRAST_THEME)
+
+            theme = self.wm_settings.get_string(KEY_WM_THEME)
+            self.wm_settings.set_string(KEY_WM_THEME_BACKUP, theme)
             self.wm_settings.set_string(KEY_WM_THEME, HIGH_CONTRAST_THEME)
         else:
-            ret = self.iface_settings.get_default_value(KEY_GTK_THEME).get_string()
-            self.iface_settings.reset(KEY_ICON_THEME)
-            self.wm_settings.reset(KEY_WM_THEME)
+            ret = self.iface_settings.get_string(KEY_GTK_THEME_BACKUP)
+
+            theme = self.iface_settings.get_string(KEY_ICON_THEME_BACKUP)
+            self.iface_settings.set_string(KEY_ICON_THEME, theme)
+
+            theme = self.wm_settings.get_string(KEY_WM_THEME_BACKUP)
+            self.wm_settings.set_string(KEY_WM_THEME, theme)
 
         return ret
 
@@ -452,5 +485,3 @@ class Module:
             ret = self.iface_settings.get_default_value(KEY_TEXT_SCALING_FACTOR).get_double()
 
         return ret
-
-
